import { getUid, getUp3, getPosko, getUlp,getUidRegional } from '@/utils/network'
import { ref } from 'vue'
import { usePostsStore } from '@/stores/posts'
import { useUp3Store } from '@/stores/up3'
import { useRegionStore } from '@/stores/region'
import { useUlpStore } from '@/stores/ulp'

interface Item {
  id: any;
  name: any;
}
const months = [
  { id: 1, name: 'Januari' },
  { id: 2, name: 'Februari' },
  { id: 3, name: 'Maret' },
  { id: 4, name: 'April' },
  { id: 5, name: 'Mei' },
  { id: 6, name: 'Juni' },
  { id: 7, name: 'Juli' },
  { id: 8, name: 'Agustus' },
  { id: 9, name: 'September' },
  { id: 10, name: 'Oktober' },
  { id: 11, name: 'November' },
  { id: 12, name: 'Desember' },
]

// create 4 year back array
const year = new Date().getFullYear();
let years = ref<Item[]>([]);
for (let i = 0; i < 5; i++) {
  years.value.push({ id: year - i, name: year - i })
}

const timeout = ref()
const itemsUid = ref<Item[]>([]);
const itemsUp3 = ref<Item[]>([]);
const itemsPosko = ref<Item[]>([]);
const itemsUlp = ref<Item[]>([]);
const itemsRegional = ref<Item[]>([]);
const itemsMedia = ref<Item[]>([]);
const fetchRegional = () => {
  itemsRegional.value = [
    { id: "1", name: "Wilayah Sumatera" },
    { id: "2", name: "Wilayah Jawa Bali" },
    { id: "3", name: "Wilayah Kalimantan" },
    { id: "4", name: "Wilayah Sulawesi" },
    { id: "5", name: "Wilayah Nusa Tenggara" },
    { id: "6", name: "Wilayah Maluku Papua" },
  ]
}
const fetchStatus = (data : any) => {

  const status  = [
    {"id": "8", "name": "Selesai"},
    {"id": "7", "name": "Nyala"},
    {"id": "6", "name": "Pengalihan"},
    {"id": "5", "name": "Dialihkan"},
    {"id": "4", "name": "Dalam Pengerjaan"},
    {"id": "3", "name": "Dalam Perjalanan"},
    {"id": "2", "name": "Penugasan Regu"},
    {"id": "1", "name": "lapor"}
  ]
  const filteredStatus = status.find(item => item.id == data);
  const name = filteredStatus ? filteredStatus.name : null;
  return name;
}
const fetchMedia = () => {
  itemsMedia.value = [
    { id: "Ulasan Aplikasi PLN Mobile", name: "Ulasan Aplikasi PLN Mobile" },
    { id: "Twitter", name: "Twitter" },
    { id: "PLN Mobile", name: "PLN Mobile" },
    { id: "Media Massa", name: "Media Massa" },
    { id: "Live Chat Website", name: "Live Chat Website" },
    { id: "Live Chat PLN Mobile", name: "Live Chat PLN Mobile" },
    { id: "Instagram", name: "Instagram" },
    { id: "Facebook", name: "Facebook" },
    { id: "Email", name: "Email" },
    { id: "EMS", name: "EMS" },
    { id: "Datang ke Kantor", name: "Datang ke Kantor" },
    { id: "Call ke Kantor Unit", name: "Call ke Kantor Unit" },
    { id: "Call PLN 123", name: "Call PLN 123" },
  ]

}
// Fetch data from the API using Axios
const fetchUid = async () => {
  try {
    const res = await getUid()
    itemsUid.value = res.data.map((item: any) => (
      {
        id: item.id,
        name: item.nama,
      }
    ));
  } catch (error) {
    console.error('Error fetching data:', error);
  }
};
const fetchUidWithRegional = async (regional: number) => {
  try {
    const res = await getUidRegional(regional)
    itemsUid.value = res.data.map((item: any) => (
      {
        id: item.id,
        name: item.nama,
      }
    ));
  } catch (error) {
    console.error('Error fetching data:', error);
  }
}
const fetchDataUp3 = async (uid: number) => {
  try {
    const res = await getUp3(uid)
    itemsUp3.value = res.data.map((item: any) => ({
      id: item.id,
      name: item.nama
    }))
  } catch (error) {
    console.error('Error fetching data:', error)
  }
}
const fetchDataUlp = async (up3: number) => {
  try {
    const res = await getUlp(up3)
    itemsUlp.value = res.data.map((item: any) => (
      {
        id: item.id,
        name: item.nama,
      }
    ));
  } catch (error) {
    console.error('Error fetching data:', error)
  }
}
const fetchDataPosko = async (up3: number) => {
  clearTimeout(timeout.value)
  timeout.value = setTimeout(async () => {
    try {
      const res = await getPosko(up3)
      itemsPosko.value = res.data.map((item: any) => (
        {
          id: item.id,
          name: item.nama,
        }
      ));
    } catch (error) {
      console.error('Error fetching data:', error);
    }
  }, 300);
};
const selectedUid = (value: any) => {
  useRegionStore().setData(value.id)
  fetchDataUp3(value.id)
}
const selectedUp3Posko = (value: any) => {
  if (value.id != 0) {
    useUp3Store().setData(value.id)
    fetchDataPosko(value.id)
  }
}
const selectedUp3Ulp = (value: any) => {
  useUp3Store().setData(value.id)
  fetchDataUlp(value.id)
}
const selectedPosko = (value: any) => {
  usePostsStore().setData(value.id)
}
const selectedUlp = (value: any) => {
  useUlpStore().setData(value.id)
}

export { selectedUid, selectedUp3Posko, selectedUp3Ulp, selectedPosko, selectedUlp, fetchMedia,fetchStatus,fetchRegional, fetchUid, itemsUid, itemsUp3, itemsPosko, itemsRegional, itemsMedia, itemsUlp, months, years };
